@@ -38,10 +38,12 @@
 #include "gdmcomm.h"
 #include "gdmconfig.h"
 #include "gdmuser.h"
+
 #include "greeter.h"
 #include "greeter_item_ulist.h"
 #include "greeter_parser.h"
 #include "greeter_configuration.h"
+#include "greeter_item.h"
 
 static GList      *users = NULL;
 static GList      *users_string = NULL;
@@ -50,9 +52,9 @@ static GHashTable *displays_hash = NULL;
 
 static GtkWidget  *pam_entry = NULL;
 static GtkWidget  *user_list = NULL;
-
 static gboolean    selecting_user = FALSE;
 static gchar      *selected_user = NULL;
+static int         num_users = 0;
 
 enum
 {
@@ -62,12 +64,40 @@ enum
 	GREETER_ULIST_ACTIVE_COLUMN
 };
 
+/* Hide the userlist if there are no users displayed */
+void
+greeter_item_ulist_check_show_userlist (void)
+{
+	/*
+	 * If there are no users, then hide the rectangle used to contain the
+	 * userlist.  This id allows a rectangle to be defined with alpha
+	 * behind the userlist that also goes away when the list is empty.
+	 */
+	if (num_users == 0) {
+		GreeterItemInfo *urinfo = greeter_lookup_id ("userlist-rect");
+		GnomeCanvasItem *item;
+
+		gtk_widget_hide (user_list);
+
+		if (urinfo) {
+			if (urinfo->group_item != NULL)
+				item = GNOME_CANVAS_ITEM (urinfo->group_item);
+			else
+				item = urinfo->item;
+
+			gnome_canvas_item_hide (item);
+		}
+	}
+}
+
 void
 greeter_item_ulist_unset_selected_user (void)
 {
 	GtkTreeSelection *selection;
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (user_list));
-	gtk_tree_selection_unselect_all (selection);
+        if (user_list != NULL) {
+		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (user_list));
+		gtk_tree_selection_unselect_all (selection);
+	}
 
 	if (selected_user != NULL)
 		g_free (selected_user);
@@ -186,6 +216,7 @@ greeter_populate_user_list (GtkTreeModel *tm)
 				    GREETER_ULIST_ACTIVE_COLUMN, active,
 				    -1);
 		g_free (label);
+		num_users++;
 	}
 }
 
